import { expect, test } from "./frontendTests"

/* 
This file contains test cases for the frontend of the app
It covers the following section:

1. Testing UI when a brand is identified


Testing helps ensure maintainability and covers functional requirement 11
 */

//Testing UI when a brand is identified
test.beforeEach("Display the extension popup", async ({ page }) => {
  console.log(`Running ${test.info().title}`)
  await page.goto(
    "https://www.zalando.co.uk/adidas-originals-gazelle-indoor-unisex-trainers-cream-whitecollegiate-green-ad115o1pl-a11.html",
  )
})

//Checking if the brand name displayed is correct
//Covers functional requirements 1, 2, 3
test("Valid: Brand name test", async ({ page }) => {
  await expect(page.getByText("Brand: Adidas")).toBeVisible()
})

//Checking if the general metrics displayed are correct
//Covers functional requirement 4
test("Valid: Brand metrics", async ({ page }) => {
  await expect(
    page.getByText("Environmental 86 Supply Chain 92 Social 92"),
  ).toBeVisible()
})

//Checking if the advanced metrics are displayed after clicking a button
//Covers functional requirement 5
test("Valid: Brand advanced data", async ({ page }) => {
  await page.getByText("Environmental").click()
  await expect(page.getByText("Advanced metrics:")).toBeVisible()
})

//Checking if hovering over an advanced metric displays popover with explanation
//Covers functional requirement 6
test("Valid: Advanced popover", async ({ page }) => {
  await page.getByText("Environmental").click()
  await page.getByText("Biodiversity").hover()
  await expect(
    page.getByText(
      "Evidence of biodiversity conservation measures. Best practice aligns with EU Best Available Techniques (BATs). However, EU BATs should not be used in place of more ambitious, local legal standards.",
    ),
  ).toBeVisible()
})

//Checking if the suggestions are displayed and correct
//Covers functional requirement 7
test("Valid: Brand suggestions", async ({ page }) => {
  await expect(page.getByText("Similar sportswear brands:")).toBeVisible()
  await expect(page.getByText("Nike 100 92 62")).toBeVisible()
  await expect(page.getByText("Puma 100 88 77")).toBeVisible()
})

//Checking if the list of all brands is displayed
//Covers functional requirement 8
test("Valid: All brands display", async ({ page }) => {
  await page.getByRole("button").filter({ hasText: "See more" }).click()
  await expect(
    page.getByRole("button").filter({ hasText: "Categories" }),
  ).toBeVisible()
  await expect(
    page.getByRole("button").filter({ hasText: "Sort by" }),
  ).toBeVisible()
  //Checks one element of the list to ensure it was rendered
  await expect(page.getByText("AJIO 57 29 62")).toBeVisible()
})

//Checking if each entry in the list can be clicked to display advanced metrics for that brand
//Covers functional requirement 9
test("Valid: Compare brands metrics", async ({ page }) => {
  await page.getByRole("button").filter({ hasText: "See more" }).click()
  await expect(page.getByText("ASICS 100 83 100")).toBeVisible()
  await page.getByRole("button").filter({ hasText: "ASICS 100 83 100" }).click()
  await expect(page.getByText("Brand: Asics")).toBeVisible()
  await expect(
    page.getByText("Environmental 100 Supply Chain 83 Social 100"),
  ).toBeVisible()
})

//An end-to-end workflow test
//Making sure all components interact seamlessly
test("Valid: End-to-end workflow", async ({ page }) => {
  await expect(page.getByText("Brand: Adidas")).toBeVisible()
  await expect(
    page.getByText("Environmental 86 Supply Chain 92 Social 92"),
  ).toBeVisible()
  await page.getByText("Environmental").click()
  await expect(page.getByText("Advanced metrics:")).toBeVisible()
  await page.getByText("Biodiversity").hover()
  await expect(
    page.getByText(
      "Evidence of biodiversity conservation measures. Best practice aligns with EU Best Available Techniques (BATs). However, EU BATs should not be used in place of more ambitious, local legal standards.",
    ),
  ).toBeVisible()
  await page.getByText("Environmental").click()
  await expect(
    page.getByText(
      "Similar sportswear brands: Nike 100 92 62 AdvancedPuma 100 88 77 Advanced",
    ),
  ).toBeVisible()
  await expect(page.getByText("Similar sportswear brands:")).toBeVisible()
  await expect(page.getByText("Nike 100 92 62")).toBeVisible()
  await expect(page.getByText("Puma 100 88 77")).toBeVisible()
  await page.getByRole("button").filter({ hasText: "See more" }).click()
  await page.getByRole("button").filter({ hasText: "Categories" }).click()
  await page.getByRole("button").filter({ hasText: "luxury" }).click()
  await page.getByRole("button").filter({ hasText: "Sort by" }).click()
  await page.getByRole("button").filter({ hasText: "social" }).click()
  await expect(page.getByText("Gucci 100 96 100")).toBeVisible()
  await page.getByRole("button").filter({ hasText: "Gucci 100 96 100" }).click()
  await expect(page.getByText("Brand: Gucci")).toBeVisible()
  await expect(
    page.getByText("Environmental 100 Supply Chain 96 Social 100"),
  ).toBeVisible()
  await page.getByAltText("go back").click()
  await page.getByAltText("store button").click()
  await expect(page.getByText("Store: Zalando")).toBeVisible()
  await expect(
    page.getByText("Environmental 71 Supply Chain 58 Social 46"),
  ).toBeVisible()
  await page.getByTitle("Close window").click()
  await expect(page.locator(".plasmo-csui-container")).toBeEmpty()
})
